@@ -16,7 +16,10 @@ class DatabaseSchemaEditor(MySqlDatabaseSchemaEditor, ABC):
 
         # 字段默认值是否写入到sql语句中处理，可在settings.py中配置
         include_default_fun = self.connection.settings_dict.get('INCLUDE_DEFAULT', None)
-        if include_default is not None:
+
+        if isinstance(include_default_fun, bool):
+            include_default = include_default_fun
+        elif include_default_fun is not None:
             include_default = include_default_fun(model, field, include_default, self.connection)
 
         # 生成sql
