@@ -11,10 +11,10 @@ from importlib import import_module
 
 from django.conf import settings
 
-STATUS_CHOICES = [(-1, '草稿'), (0, '待审'), (1, '通过'), (2, '驳回')]
+STATUS_CHOICES: list = [(-1, '草稿'), (0, '待审'), (1, '通过'), (2, '驳回')]
 
 
-def load_object(path):
+def load_object(path: str):
     """
     Load an object given its absolute object path, and return it.
     object can be a class, function, variable or an instance.
@@ -27,7 +27,7 @@ def load_object(path):
     return getattr(mod, name)
 
 
-def get_kelove_databases_settings(key=None, default=None):
+def get_kelove_databases_settings(key: str = None, default=None):
     """
     获取配置
     :param key:
